There are a number of ways to build an AEA:

- To start with, we recommended you build an AEA project step-by-step with the CLI tool as demonstrated in the quick start guide and described here.
- Using the CLI `aea fetch` command, pull in an already built project and run as is or extend it to your needs.
- The last option is to build an AEA programmatically as described here.

Sometimes, an AEA is more than is required for the task at hand. In particular, an AEA is much more than just an agent. In those cases, we suggest you have a look at the following two guides:

- the AEA vs Agents guide shows the difference between an agent and an AEA in code,
- the Use multiplexer standalone guide shows how to use the multiplexer on its own to receive and send envelopes.